#include "pscol.h"

/**********************************************************************/
/*                                                                    */
/* convtype: converts the numberacle type to a word                   */
/*                                                                    */
/**********************************************************************/

char *convtype(int markup)
{
 char *nametype[] = {"unk", "user", "state", "mem", "cpu", "size", "tty", 0};

 if (markup < 1 || markup > 6) markup = 1;
 return strdup(nametype[markup - 1]);
}
